plugins.core.navigation package
===============================

Submodules
----------

plugins.core.navigation.help module
-----------------------------------

.. automodule:: plugins.core.navigation.help
   :members:
   :undoc-members:
   :show-inheritance:

plugins.core.navigation.paginator module
----------------------------------------

.. automodule:: plugins.core.navigation.paginator
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: plugins.core.navigation
   :members:
   :undoc-members:
   :show-inheritance:
